Module module

Module module 

Script parsing utilities

Structs

Cons
A Type which represents two types H and T
Nil
A Type which represents the empty Type

Traits

Module
Types which implement Module can compile a line into a Func and multiple lines into a Script through instance methods
ModuleType
Types which implement ModuleType can compile a line into a Func and multiple lines into a Script

Type Aliases

ModuleList
A list of FuncMatchers for a given context. Output of mod_list! macro