pub enum Trap {
DowncastError(&'static str),
ScriptOutOfBounds,
MissingGlobal(String),
Runtime(String),
}Expand description
An error which may occur during running a function
Variants
DowncastError(&'static str)
The type of the global differs than the requested type
ScriptOutOfBounds
The script could not execute the given function
MissingGlobal(String)
A variable is missing
Runtime(String)
Another custom runtime error
Implementations